package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.xlk.entity.SceneLog;
import com.yunzhi.marketing.xlk.service.ISceneLogService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 业务日志记录表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-10-08
 */
@RestController
@RequestMapping("/api")
@Api(value = "", tags = "xlk-")
public class SceneLogController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SceneLogController.class);

    @Autowired
    public ISceneLogService iSceneLogService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/sceneLog",method= RequestMethod.GET)
    public ResponseBean sceneLogList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                     @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                     @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SceneLog> pg = new Page<>(pageNum, pageSize);
            LambdaQueryWrapper<SceneLog> queryWrapper = new LambdaQueryWrapper<>();

            IPage<SceneLog> result = iSceneLogService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sceneLogList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sceneLog 实体对象
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/sceneLog",method= RequestMethod.POST)
    public ResponseBean sceneLogAdd(@RequestBody SceneLog sceneLog, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSceneLogService.save(sceneLog)){
                responseBean.addSuccess(sceneLog);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sceneLogAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @ResponseBody
    @RequestMapping(value="/sceneLog/{id}", method= RequestMethod.DELETE)
    public ResponseBean sceneLogDelete(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSceneLogService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sceneLogDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sceneLog 实体对象
     * @return
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/sceneLog/{id}",method= RequestMethod.PUT)
    public ResponseBean sceneLogUpdate(@PathVariable String id,
                                       @RequestBody SceneLog sceneLog, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSceneLogService.updateById(sceneLog)){
                responseBean.addSuccess(sceneLog);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sceneLogUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @ApiOperation(value = "", notes = "")
    @RequestMapping(value="/sceneLog/{id}",method= RequestMethod.GET)
    public ResponseBean sceneLogGet(@PathVariable String id, @RequestHeader("authorization") String token, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSceneLogService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sceneLogDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
